"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "number-unitized-zero";
exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expected: "Expected a unit for \"0\" value",
  rejected: "Unexpected unit for \"0\" value" });

exports.messages = messages;
/**
 * @param {"always"|"never"} expectation
 */

exports["default"] = function (expectation) {
  return function (css, result) {
    css.eachDecl(function (decl) {
      var value = decl.value;

      var valuesContainingZero = value.match(/[#\b]\S*0\S*\b/g);

      valuesContainingZero.forEach(function (num) {
        // Ignore colors
        if (num[0] === "#") {
          return;
        }

        // Ignore values that do not parse to zero
        if (parseInt(num, 10)) {
          return;
        }

        if (/\D/.test(num.slice(-1))) {
          result.warn(messages.rejected, { node: decl });
        }
      });
    });
  };
};